# twi

Send tweets, change your Twitter profile description, and delete your last tweet, all from the comfort of your sweet-smelling CLI!

# Installation
```bash
> pip install twi
```

# Usage
```bash
> tw "hey this is my tweet"
Okay, published the tweet at https://twitter.com/yourname/status/12344556
> prof "hey this is my new twitter profile description"
okay, updated profile
> dtw
Okay, deleted your last tweet, ID "abcdefghijkl12345".
```
